@@ -3,9 +3,12 @@
 
 #' @title aqs_qa_blanks_by_MA
 #' @description \lifecycle{stable}
-#'   Returns a tibble or an AQS_Data Mart_APIv2 S3
-#'   object containing Quality assurance - blanks sample data aggregated by
-#'   monitoring agency code (_by_MA).
+#'        Returns a table of blank quality assurance data.
+#'        Blanks are unexposed sample collection devices (e.g.,
+#'        filters) that are transported with the exposed sample devices
+#'        to assess if contamination is occurring during the transport
+#'        or handling of the samples. Data is aggregated by monitoring agency
+#'        code (MA_code).
 #' @note The AQS API only allows for a single year of qa_blank data to be
 #'         retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
@@ -31,8 +34,8 @@
 #'           information from the AQS API and the second item ($Data) is a
 #'           tibble of the data returned.
 #' @examples # returns a tibble containing PM2.5 blank data for
-#'            #  January 2018 where the Monitoring Agency is the Alabama
-#'            #  Department of Environmental Management (agency 0013)
+#'           #  January 2018 where the Monitoring Agency is the Alabama
+#'           #  Department of Environmental Management (agency 0013)
 #'           \dontrun{aqs_qa_blanks_by_MA(parameter = "88101",
 #'                                        bdate = as.Date("20170101",
 #'                                                        format = "%Y%m%d"),
@@ -47,6 +50,9 @@ aqs_qa_blanks_by_MA <- function(parameter, bdate, edate, MA_code,
                                 return_header = FALSE
                                 )
 {
+  checkaqsparams(parameter, bdate, edate, MA_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -92,8 +98,8 @@ aqs_qa_blanks_by_MA <- function(parameter, bdate, edate, MA_code,
 #'           from the AQS API and the second item ($Data) is a tibble of the
 #'           data returned.
 #' @examples # returns a tibble containing collocated assessment
-#'           #  data for FRM PM2.5 January 2013 where the Monitoring Agency is
-#'           #  the Alabama Department of Environmental Management (agency 0013)
+#'           #   data for FRM PM2.5 January 2013 where the Monitoring Agency is
+#'           #   the Alabama Department of Environmental Management (agency 0013)
 #'           \dontrun{aqs_qa_collocated_assessments_by_MA(parameter="88101",
 #'                                                   bdate = as.Date("20130101",
 #'                                                           format = "%Y%m%d"),
@@ -110,6 +116,9 @@ aqs_qa_collocated_assessments_by_MA <- function(parameter, bdate,
                                                 return_header = FALSE
                                                 )
 {
+  checkaqsparams(parameter, bdate, edate, MA_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -155,9 +164,10 @@ aqs_qa_collocated_assessments_by_MA <- function(parameter, bdate,
 #'           which the first item ($Header) is a tibble of header information
 #'           from the AQS API and the second item ($Data) is a tibble of the
 #'           data returned.
-#' @examples # returns a tibble containing collocated assessment
-#'   #  data for FRM PM2.5 January 2013 where the Monitoring Agency is
-#'   #  the Alabama Department of Environmental Management (agency 0013)
+#' @examples
+#'   # returns a tibble containing collocated assessment
+#'   #   data for FRM PM2.5 January 2013 where the Monitoring Agency is
+#'   #   the Alabama Department of Environmental Management (agency 0013)
 #'   \dontrun{aqs_qa_flowrateverification_by_MA(parameter = "88101",
 #'                                              bdate = as.Date("20130101",
 #'                                                             format = "%Y%m%d"
@@ -174,6 +184,9 @@ aqs_qa_flowrateverification_by_MA <- function(parameter, bdate, edate,
                                               cedate = NA_Date_,
                                               return_header = FALSE)
 {
+  checkaqsparams(parameter, bdate, edate, MA_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -218,9 +231,10 @@ aqs_qa_flowrateverification_by_MA <- function(parameter, bdate, edate,
 #'           first item (\$Header) is a tibble of header information from the
 #'           AQS API and the second item (\$Data) is a tibble of the data
 #'           returned.
-#' @examples # returns a tibble of flow rate audit data
-#'  #  for FRM PM2.5 January 2016 - Januray 2018 where the Monitoring Agency is
-#'  #  the Jefferson County, AL  Department of Health (agency 0550)
+#' @examples
+#'  # returns a tibble of flow rate audit data
+#'  #   for FRM PM2.5 January 2016 - Januray 2018 where the Monitoring Agency is
+#'  #   the Jefferson County, AL  Department of Health (agency 0550)
 #'  \dontrun{aqs_qa_flowrateaudit_by_MA(parameter = "88101",
 #'                                      bdate = as.Date("20160101",
 #'                                                   format = "%Y%m%d"),
@@ -236,7 +250,9 @@ aqs_qa_flowrateaudit_by_MA <- function(parameter, bdate, edate, MA_code,
                                        return_header = FALSE
                                        )
 {
- params <- aqsmultiyearparams(parameter = parameter,
+  checkaqsparams(parameter, bdate, edate, MA_code, cbdate, cedate,
+                 return_header)
+  params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
                                MA_code = MA_code,
@@ -253,9 +269,9 @@ aqs_qa_flowrateaudit_by_MA <- function(parameter, bdate, edate, MA_code,
 
 #' @title aqs_qa_one_point_qc_by_MA
 #' @description \lifecycle{stable}
-#'   Returns a tibble or an AQS_Data Mart_APIv2 S3 object containing Quality
-#'   assurance data - collocated assessment raw data aggregated by monitoring
-#'   agency code (_by_MA).
+#'                Returns a tibble or an AQS_Data Mart_APIv2 S3 object
+#'                containing one point QC check data aggregated by monitoring
+#'                agency code (_by_MA).
 #' @note The AQS API only allows for a single year of one point qc data to
 #'         be retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
@@ -297,6 +313,9 @@ aqs_qa_one_point_qc_by_MA <- function(parameter, bdate, edate, MA_code,
                                       return_header = FALSE
                                       )
 {
+  checkaqsparams(parameter, bdate, edate, MA_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -357,6 +376,9 @@ aqs_qa_pep_audit_by_MA <- function(parameter, bdate, edate, MA_code,
                                    cbdate = NA_Date_, cedate = NA_Date_,
                                    return_header = FALSE)
 {
+  checkaqsparams(parameter, bdate, edate, MA_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -380,7 +402,7 @@ aqs_qa_pep_audit_by_MA <- function(parameter, bdate, edate, MA_code,
 #'          monitoring agency (MA) code provided for bdate - edate time
 #'          frame. Includes data both in submitted and standard units
 #'
-#' @note The AQS API only allows for a single year of transactiondata to be
+#' @note The AQS API only allows for a single year of transaction data to be
 #'         retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
 #'         calls to the AQSAPI retrieving a maximum of one calendar year of
@@ -421,6 +443,9 @@ aqs_transactionsample_by_MA <- function(parameter, bdate, edate, MA_code,
                                 return_header = FALSE
                                 )
 {
+  checkaqsparams(parameter, bdate, edate, MA_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -432,3 +457,136 @@ aqs_transactionsample_by_MA <- function(parameter, bdate, edate, MA_code,
   if (!return_header) transactionsample %<>% aqs_removeheader
   return(transactionsample)
 }
+
+
+#' @title aqs_qa_annualpeferomanceeval_by_MA
+#' @description \lifecycle{stable}
+#'        Returns quality assurance performance evaluation data - aggregated by
+#'          by Monitoring agency (MA) for a parameter
+#'          code aggregated by matching input parameter and MA_code for the
+#'          time frame between bdate and edate.
+#' @note The AQS API only allows for a single year of quality assurance
+#'         Annual Performance Evaluation data to be retrieved at a
+#'         time. This function conveniently extracts date information from the
+#'         bdate and edate parameters then makes repeated calls to the AQSAPI
+#'         retrieving a maximum of one calendar year of data at a time. Each
+#'         calendar year of data requires a separate API call so multiple years
+#'         of data will require multiple API calls. As the number of years of
+#'         data being requested increases so does the length of time that it
+#'         will take to retrieve results. There is also a 5 second wait time
+#'         inserted between successive API calls to prevent overloading the API
+#'         server. This operation has a linear run time of
+#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @family Aggregate _by_MA functions
+#' @inheritParams aqs_services_by_MA
+#' @param return_header If FALSE (default) only returns data requested.
+#'                        If TRUE returns a AQSAPI_v2 object which is a two
+#'                        item list that contains header information returned
+#'                        from the API server mostly used for debugging
+#'                        purposes in addition to the data requested.
+#' @importFrom magrittr `%<>%`
+#' @examples
+#'           #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
+#'           #  containing annual performance evaluation data for ozone where
+#'           #  the monitoring agency is the Alabama Department of
+#'           #  Environmental Management (MA_code 0013).
+#'           \dontrun{aqs_qa_annualpeferomanceeval_by_pqao(parameter = "44201",
+#'                                                   bdate = as.Date("20170101",
+#'                                                           format = "%Y%m%d"),
+#'                                                   edate = as.Date("20171231",
+#'                                                           format = "%Y%m%d"),
+#'                                                           MA_code = "0013"
+#'                                                         )
+#'                   }
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of quality assurance
+#'           performance evaluation data. for single monitoring site for the
+#'           sitenum, countycode and stateFIPS requested for the time frame
+#'           between bdate and edate. An AQS_Data_Mart_APIv2 is a 2 item named
+#'           list in which the first item ($Header) is a tibble of header
+#'           information from the AQS API and the second item ($Data) is a
+#'           tibble of the data returned.
+#' @export
+aqs_qa_annualpeferomanceeval_by_MA <- function(parameter, bdate, edate,
+                                               MA_code,
+                                               return_header = FALSE)
+{
+  checkaqsparams(parameter, bdate, edate, MA_code, return_header)
+
+  params <- aqsmultiyearparams(parameter = parameter,
+                               bdate = bdate,
+                               edate = edate,
+                               MA_code = MA_code,
+                               service = "qaAnnualPerformanceEvaluations"
+                               )
+
+  qaape <- purrr::pmap(.l = params, .f = aqs_services_by_MA)
+  if (!return_header) qaape %<>% aqs_removeheader
+  return(qaape)
+}
+
+
+#' @title aqs_qa_annualperformanceevaltransaction_by_site
+#' @description \lifecycle{stable}
+#'          Returns AQS submissions transaction format (RD) of the annual
+#'             performance evaluation data (raw). Includes data pairs for
+#'             QA - aggregated by Monitoring agency (MA)
+#'             for a parameter code aggregated by matching input parameter and
+#'             MA_code provided for bdate - edate time frame.
+#' @note The AQS API only allows for a single year of quality assurance Annual
+#'         Performance Evaluation transaction data to be retrieved at a time.
+#'         This function conveniently extracts date information from the bdate
+#'         and edate parameters then makes repeated calls to the AQSAPI
+#'         retrieving a maximum of one calendar year of data at a time. Each
+#'         calendar year of data requires a separate API call so multiple years
+#'         of data will require multiple API calls. As the number of years of
+#'         data being requested increases so does the length of time that it
+#'         will take to retrieve results. There is also a 5 second wait time
+#'         inserted between successive API calls to prevent overloading the API
+#'         server. This operation has a linear run time of
+#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @family Aggregate _by_MA functions
+#' @inheritParams aqs_services_by_MA
+#' @param return_header If FALSE (default) only returns data requested.
+#'                        If TRUE returns a AQSAPI_v2 object which is a two
+#'                        item list that contains header information returned
+#'                        from the API server mostly used for debugging
+#'                        purposes in addition to the data requested.
+#' @importFrom magrittr `%<>%`
+#' @examples #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
+#'           #   containing annual performance evaluation data for ozone in
+#'           #   where the MA is the Alabama Department of Environmental
+#'           #   Management (MA_code 0013) for 2017 in RD format.
+#'  \dontrun{aqs_qa_annualperformanceevaltransaction_by_MA(parameter = "44201",
+#'                                               bdate = as.Date("20170101",
+#'                                                           format = "%Y%m%d"),
+#'                                               edate = as.Date("20171231",
+#'                                                           format = "%Y%m%d"),
+#'                                               MA_code = "0013"
+#'                                              )
+#'          }
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of quality assurance
+#'           performance evaluation data. for single monitoring site for the
+#'           sitenum, countycode and stateFIPS requested for the time frame
+#'           between bdate and edate. An AQS_Data_Mart_APIv2 is a 2 item named
+#'           list in which the first item ($Header) is a tibble of header
+#'           information from the AQS API and the second item ($Data) is a
+#'           tibble of the data returned.
+#' @export
+aqs_qa_annualperformanceevaltransaction_by_MA <- function(parameter,
+                                                                bdate, edate,
+                                                                MA_code,
+                                                          return_header = FALSE)
+{
+  checkaqsparams(parameter, bdate, edate, MA_code, return_header)
+
+  params <- aqsmultiyearparams(parameter = parameter,
+                               bdate = bdate,
+                               edate = edate,
+                               MA_code = MA_code,
+                               service = "qaAnnualPerformanceEvaluations"
+                               )
+
+  tqaape <- purrr::pmap(.l = params, .f = aqs_services_by_MA)
+  if (!return_header) tqaape %<>% aqs_removeheader
+  return(tqaape)
+}
