@@ -2,9 +2,12 @@
 
 #' @title aqs_qa_blanks_by_pqao
 #' @description \lifecycle{stable}
-#'   Returns a tibble or an AQS_Data Mart_APIv2 S3
-#'   object containing Quality assurance data - blanks sample data aggregated
-#'   by Primary Quality Assurance Organization (PQAO) code.
+#'        Returns a table of blank quality assurance data.
+#'        Blanks are unexposed sample collection devices (e.g.,
+#'        filters) that are transported with the exposed sample devices
+#'        to assess if contamination is occurring during the transport
+#'        or handling of the samples. Data is aggregated by
+#'        Primary Quality Assurance Organization (PQAO).
 #' @note The AQS API only allows for a single year of qa_blank data to be
 #'         retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
@@ -45,6 +48,9 @@ aqs_qa_blanks_by_pqao <- function(parameter, bdate, edate, pqao_code,
                                   return_header = FALSE
                                   )
 {
+  checkaqsparams(parameter, bdate, edate, pqao_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -107,6 +113,9 @@ aqs_qa_collocated_assessments_by_pqao <- function(parameter, bdate, edate,
                                                   return_header = FALSE
                                                   )
 {
+  checkaqsparams(parameter, bdate, edate, pqao_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -172,6 +181,9 @@ aqs_qa_flowrateverification_by_pqao <- function(parameter, bdate, edate,
                                                 return_header = FALSE
                                                 )
 {
+  checkaqsparams(parameter, bdate, edate, pqao_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -234,6 +246,9 @@ aqs_qa_flowrateaudit_by_pqao <- function(parameter, bdate, edate, pqao_code,
                                          return_header = FALSE
                                          )
 {
+  checkaqsparams(parameter, bdate, edate, pqao_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -294,6 +309,9 @@ aqs_qa_one_point_qc_by_pqao <- function(parameter, bdate, edate, pqao_code,
                                         return_header = FALSE
                                         )
 {
+  checkaqsparams(parameter, bdate, edate, pqao_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -357,6 +375,9 @@ aqs_qa_pep_audit_by_pqao <- function(parameter, bdate, edate, pqao_code,
                                      return_header = FALSE
                                      )
 {
+  checkaqsparams(parameter, bdate, edate, pqao_code, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -370,3 +391,135 @@ aqs_qa_pep_audit_by_pqao <- function(parameter, bdate, edate, pqao_code,
   if (!return_header) pepaudit %<>% aqs_removeheader
   return(pepaudit)
 }
+
+
+#' @title aqs_qa_annualpeferomanceeval_by_pqao
+#' @description \lifecycle{stable}
+#'        Returns quality assurance performance evaluation data - aggregated by
+#'          Primary Quality Assurance Organization (PQAO) for a parameter
+#'          code aggregated by matching input parameter and pqao_code for the
+#'          time frame between bdate and edate.
+#' @note The AQS API only allows for a single year of
+#'         qaAnnualPerformanceEvaluations to be retrieved at a time. This
+#'         function conveniently extracts date information from the bdate
+#'         and edate parameters then makes repeated calls to the AQSAPI
+#'         retrieving a maximum of one calendar year of data at a time. Each
+#'         calendar year of data requires a separate API call so multiple years
+#'         of data will require multiple API calls. As the number of years of
+#'         data being requested increases so does the length of time that it
+#'         will take to retrieve results. There is also a 5 second wait time
+#'         inserted between successive API calls to prevent overloading the API
+#'         server. This operation has a linear run time of
+#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @family Aggregate _by_pqao functions
+#' @inheritParams aqs_services_by_pqao
+#' @param return_header If FALSE (default) only returns data requested.
+#'                        If TRUE returns a AQSAPI_v2 object which is a two
+#'                        item list that contains header information returned
+#'                        from the API server mostly used for debugging
+#'                        purposes in addition to the data requested.
+#' @importFrom magrittr `%<>%`
+#' @examples #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
+#'           #   containing annual performance evaluation data for ozone where
+#'           #   the PQAO is the Alabamaba Department of Environmental
+#'           #   Management (pqao_code 0013).
+#'  \dontrun{ aqs_qa_annualpeferomanceeval_by_pqao(parameter = "44201",
+#'                                                 bdate = as.Date("20170101",
+#'                                                           format = "%Y%m%d"),
+#'                                                 edate = as.Date("20171231",
+#'                                                           format = "%Y%m%d"),
+#'                                                 pqao_code = "0013"
+#'                                                 )
+#'                  }
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of quality assurance
+#'           performance evaluation data. for single monitoring site for the
+#'           sitenum, countycode and stateFIPS requested for the time frame
+#'           between bdate and edate. An AQS_Data_Mart_APIv2 is a 2 item named
+#'           list in which the first item ($Header) is a tibble of header
+#'           information from the AQS API and the second item ($Data) is a
+#'           tibble of the data returned.
+#' @export
+aqs_qa_annualpeferomanceeval_by_pqao <- function(parameter, bdate, edate,
+                                                  pqao_code,
+                                                  return_header = FALSE)
+{
+  checkaqsparams(parameter, bdate, edate, pqao_code, return_header)
+
+  params <- aqsmultiyearparams(parameter = parameter,
+                               bdate = bdate,
+                               edate = edate,
+                               pqao_code = pqao_code,
+                               service = "qaAnnualPerformanceEvaluations"
+                               )
+
+  qaape <- purrr::pmap(.l = params, .f = aqs_services_by_pqao)
+  if (!return_header) qaape %<>% aqs_removeheader
+  return(qaape)
+}
+
+
+#' @title aqs_qa_annualperformanceevaltransaction_by_pqao
+#' @description \lifecycle{stable}
+#'          Returns AQS submissions transaction format (RD) of the annual
+#'             performance evaluation data (raw). Includes data pairs for
+#'             QA - aggregated by Primary Quality Assurance Organization (PQAO)
+#'             for a parameter code aggregated by matching input parameter and
+#'             pqao_code provided for bdate - edate time frame.
+#' @note The AQS API only allows for a single year of
+#'         qaAnnualPerformanceEvaluations to be retrieved at a time. This
+#'         function conveniently extracts date information from the bdate
+#'         and edate parameters then makes repeated calls to the AQSAPI
+#'         retrieving a maximum of one calendar year of data at a time. Each
+#'         calendar year of data requires a separate API call so multiple years
+#'         of data will require multiple API calls. As the number of years of
+#'         data being requested increases so does the length of time that it
+#'         will take to retrieve results. There is also a 5 second wait time
+#'         inserted between successive API calls to prevent overloading the API
+#'         server. This operation has a linear run time of
+#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @family Aggregate _by_pqao functions
+#' @inheritParams aqs_services_by_pqao
+#' @param return_header If FALSE (default) only returns data requested.
+#'                        If TRUE returns a AQSAPI_v2 object which is a two
+#'                        item list that contains header information returned
+#'                        from the API server mostly used for debugging
+#'                        purposes in addition to the data requested.
+#' @importFrom magrittr `%<>%`
+#' @examples #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
+#'           #   containing annual performance evaluation data for ozone in
+#'           #   where the PQAO is the Alabama Department of Environmental
+#'           #   Management (pqao_code 0013) for 2017 in RD format.
+#'  \dontrun{aqs_qa_annualperformanceevaltransaction_by_pqao(parameter = "44201",
+#'                                                 bdate = as.Date("20170101",
+#'                                                           format = "%Y%m%d"),
+#'                                                 edate = as.Date("20171231",
+#'                                                           format = "%Y%m%d"),
+#'                                                 pqao_code = "0013"
+#'                                                )
+#'                  }
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of quality assurance
+#'           performance evaluation data. for single monitoring site for the
+#'           sitenum, countycode and stateFIPS requested for the time frame
+#'           between bdate and edate. An AQS_Data_Mart_APIv2 is a 2 item named
+#'           list in which the first item ($Header) is a tibble of header
+#'           information from the AQS API and the second item ($Data) is a
+#'           tibble of the data returned.
+#' @export
+aqs_qa_annualperformanceevaltransaction_by_pqao <- function(parameter,
+                                                            bdate, edate,
+                                                            pqao_code,
+                                                          return_header = FALSE)
+{
+  checkaqsparams(parameter, bdate, edate, pqao_code, return_header)
+
+  params <- aqsmultiyearparams(parameter = parameter,
+                               bdate = bdate,
+                               edate = edate,
+                               pqao_code = pqao_code,
+                               service = "qaAnnualPerformanceEvaluations"
+                               )
+
+  tqaape <- purrr::pmap(.l = params, .f = aqs_services_by_pqao)
+  if (!return_header) tqaape %<>% aqs_removeheader
+  return(tqaape)
+}
