@@ -3,8 +3,8 @@
 
 #' @title aqs_monitors_by_state
 #' @description \lifecycle{stable}
-#'  Returns a table of monitors at all sites with the provided parameternum,
-#'    stateFIPS and county_code for bdate - edate time frame.
+#'  Returns a table of monitors and related metadata at sites with the
+#'    provided parameter, and stateFIPS for bdate - edate time frame.
 #' @family Aggregate_by_state functions
 #' @inheritParams aqs_services_by_state
 #' @importFrom magrittr `%<>%`
@@ -13,7 +13,7 @@
 #'                        list that contains header information returned from
 #'                        the API server mostly used for debugging purposes in
 #'                        addition to the data requested.
-#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of monitors from a
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of monitors from the
 #'           selected state
 #' @examples # returns a tibble of SO2 monitors in Hawaii
 #'           #  that were operating on May 01, 2015
@@ -31,8 +31,11 @@ aqs_monitors_by_state <- function(parameter, bdate, edate, stateFIPS,
                                     cbdate = NA_Date_, cedate = NA_Date_,
                                     return_header = FALSE)
 {
-   # aqs_monitors_by_* functions don't call aqsmultiyearparams() since the
-  #  monitors API call accepts multiple years of data on the server, purrr::map
+    checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                   return_header)
+
+  # aqs_monitors_by_* functions don't call aqsmultiyearparams() since the
+  #  monitors API call accepts multiple years of data on the server, purrr::pmap
   #  is used so that the output is consistent with other RAQSAPI functions.
   params <- tibble(parameter = parameter,
                    bdate = bdate,
@@ -102,14 +105,19 @@ aqs_monitors_by_state <- function(parameter, bdate, edate, stateFIPS,
 #'                    }
 #' @export
 aqs_sampledata_by_state <- function(parameter, bdate, edate, stateFIPS,
+                                    duration = NA_character_,
                                     cbdate = NA_Date_, cedate = NA_Date_,
                                     return_header = FALSE
                                     )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, duration, cbdate,
+                 cedate, return_header)
+
 params <- aqsmultiyearparams(parameter = parameter,
                                    bdate = bdate,
                                    edate = edate,
                                    stateFIPS = stateFIPS,
+                                   duration = duration,
                                    service = "sampleData",
                                    cbdate = cbdate,
                                    cedate = cedate
@@ -173,6 +181,9 @@ aqs_annualsummary_by_state <- function(parameter, bdate, edate, stateFIPS,
                                        return_header = FALSE
                                        )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -190,9 +201,11 @@ aqs_annualsummary_by_state <- function(parameter, bdate, edate, stateFIPS,
 
 #' @title aqs_qa_blanks_by_state
 #' @description \lifecycle{stable}
-#'                Returns a tibble or an AQS_Data Mart_APIv2 S3
-#'                object containing Quality assurance blank sample data
-#'                aggregated by state FIPS.
+#'        Returns a table of blank quality assurance data .
+#'        Blanks are unexposed sample collection devices (e.g.,
+#'        filters) that are transported with the exposed sample devices
+#'        to assess if contamination is occurring during the transport
+#'        or handling of the samples. Data is aggregated at the state level.
 #' @note The AQS API only allows for a single year of qa_blank data to be
 #'         retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
@@ -234,6 +247,9 @@ aqs_qa_blanks_by_state <- function(parameter, bdate, edate, stateFIPS,
                                      cbdate = NA_Date_, cedate = NA_Date_,
                                      return_header = FALSE)
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -251,8 +267,11 @@ aqs_qa_blanks_by_state <- function(parameter, bdate, edate, stateFIPS,
 
 #' @title aqs_dailysummary_by_state
 #' @description \lifecycle{stable}
-#'                Returns a tibble or an AQS_Data Mart_APIv2 S3
-#'                object containing sample data data aggregated by state FIPS.
+#'        Returns multiple years of data where daily data is
+#'        aggregated at the state level. Returned is a daily summary
+#'        matching the input parameter and stateFIPS provided for bdate - edate
+#'        time frame. Data is aggregated at the state level. Variables returned
+#'        include mean value, maxima, percentiles, and etc.
 #' @note The AQS API only allows for a single year of dailysummary to be
 #'         retrieved at a time. This function conveniently extracts date
 #'         information from the bdate and edate parameters then makes repeated
@@ -273,7 +292,7 @@ aqs_qa_blanks_by_state <- function(parameter, bdate, edate, stateFIPS,
 #'                        the API server mostly used for debugging purposes in
 #'                        addition to the data requested.
 #' @return a tibble or an AQS_Data Mart_APIv2 S3 object that contains daily
-#'           summary statistics for the given parameter for a single stateFIPS
+#'           summary statistics for the given parameter for a single stateFIPS.
 #'           An AQS_Data Mart_APIv2 is a 2 item named list in which the first
 #'           item (\$Header) is a tibble of header information from the AQS API
 #'           and the second item (\$Data) is a tibble of the data returned.
@@ -295,6 +314,9 @@ aqs_dailysummary_by_state <- function(parameter, bdate, edate, stateFIPS,
                                       return_header = FALSE
                                       )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -358,6 +380,9 @@ aqs_qa_collocated_assessments_by_state <- function(parameter, bdate, edate,
                                                    return_header = FALSE
                                                    )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -421,6 +446,9 @@ aqs_qa_flowrateverification_by_state <- function(parameter, bdate, edate,
                                                  return_header = FALSE
                                                  )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -484,6 +512,9 @@ aqs_qa_flowrateaudit_by_state <- function(parameter, bdate, edate, stateFIPS,
                                           return_header = FALSE
                                           )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -546,6 +577,9 @@ aqs_qa_one_point_qc_by_state <- function(parameter, bdate, edate, stateFIPS,
                                          return_header = FALSE
                                          )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -605,6 +639,9 @@ aqs_qa_pep_audit_by_state <- function(parameter, bdate, edate, stateFIPS,
                                       return_header = FALSE
                                       )
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, cbdate, cedate,
+                 return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -664,6 +701,8 @@ aqs_qa_pep_audit_by_state <- function(parameter, bdate, edate, stateFIPS,
 aqs_transactionsample_by_state <- function(parameter, bdate, edate, stateFIPS,
                                           return_header = FALSE)
 {
+  checkaqsparams(parameter, bdate, edate, stateFIPS, return_header)
+
   params <- aqsmultiyearparams(parameter = parameter,
                                bdate = bdate,
                                edate = edate,
@@ -675,3 +714,196 @@ aqs_transactionsample_by_state <- function(parameter, bdate, edate, stateFIPS,
   if (!return_header) transactionsample %<>% aqs_removeheader
   return(transactionsample)
 }
+
+#' @title aqs_qa_annualpeferomanceeval_by_state
+#' @description \lifecycle{stable}
+#'        Returns quality assurance performance evaluation data - aggregated by
+#'          state for a parameter code aggregated by matching input
+#'          parameter, countycode and stateFIPS provided for
+#'          bdate - edate time frame.
+#' @note The AQS API only allows for a single year of quality assurance
+#'         Annual Performance Evaluation data to be retrieved at a time. This
+#'         function conveniently extracts date information from the bdate
+#'         and edate parameters then makes repeated calls to the AQSAPI
+#'         retrieving a maximum of one calendar year of data at a time. Each
+#'         calendar year of data requires a separate API call so multiple years
+#'         of data will require multiple API calls. As the number of years of
+#'         data being requested increases so does the length of time that it
+#'         will take to retrieve results. There is also a 5 second wait time
+#'         inserted between successive API calls to prevent overloading the API
+#'         server. This operation has a linear run time of
+#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @family Aggregate _by_state functions
+#' @inheritParams aqs_services_by_state
+#' @param return_header If FALSE (default) only returns data requested.
+#'                        If TRUE returns a AQSAPI_v2 object which is a two
+#'                        item list that contains header information returned
+#'                        from the API server mostly used for debugging
+#'                        purposes in addition to the data requested.
+#' @importFrom magrittr `%<>%`
+#' @examples #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
+#'           #   containing annual performance evaluation data for ozone in
+#'           #   Alabamba for 2017.
+#'  \dontrun{ aqs_qa_annualpeferomanceeval_by_state(parameter = "44201",
+#'                                                   bdate = as.Date("20170101",
+#'                                                           format = "%Y%m%d"),
+#'                                                   edate = as.Date("20171231",
+#'                                                           format = "%Y%m%d"),
+#'                                                   stateFIPS = "01"
+#'                                                   )
+#'                  }
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of quality assurance
+#'           performance evaluation data. for single monitoring site for the
+#'           sitenum, countycode and stateFIPS requested for the time frame
+#'           between bdate and edate. An AQS_Data_Mart_APIv2 is a 2 item named
+#'           list in which the first item ($Header) is a tibble of header
+#'           information from the AQS API and the second item ($Data) is a
+#'           tibble of the data returned.
+#' @export
+aqs_qa_annualpeferomanceeval_by_state <- function(parameter, bdate, edate,
+                                                   stateFIPS,
+                                                   return_header = FALSE)
+{
+  checkaqsparams(parameter, bdate, edate, stateFIPS, return_header)
+
+  params <- aqsmultiyearparams(parameter = parameter,
+                               bdate = bdate,
+                               edate = edate,
+                               stateFIPS = stateFIPS,
+                               service = "qaAnnualPerformanceEvaluations"
+                               )
+
+  qaape <- purrr::pmap(.l = params, .f = aqs_services_by_state)
+  if (!return_header) qaape %<>% aqs_removeheader
+  return(qaape)
+}
+
+
+#' @title aqs_qa_annualperformanceevaltransaction_by_state
+#' @description \lifecycle{stable}
+#'          Returns AQS submissions transaction format (RD) of the annual
+#'             performance evaluation data (raw). Includes data pairs for
+#'             QA - aggregated by state for a parameter code aggregated by
+#'             matching input parameter and stateFIPS provided for bdate - edate
+#'             time frame.
+#' @note The AQS API only allows for a single year of quality assurance
+#'         Annual Performance Evaluation data to be retrieved at a time. This
+#'         function conveniently extracts date information from the bdate
+#'         and edate parameters then makes repeated calls to the AQSAPI
+#'         retrieving a maximum of one calendar year of data at a time. Each
+#'         calendar year of data requires a separate API call so multiple years
+#'         of data will require multiple API calls. As the number of years of
+#'         data being requested increases so does the length of time that it
+#'         will take to retrieve results. There is also a 5 second wait time
+#'         inserted between successive API calls to prevent overloading the API
+#'         server. This operation has a linear run time of
+#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @family Aggregate _by_state functions
+#' @inheritParams aqs_services_by_state
+#' @param return_header If FALSE (default) only returns data requested.
+#'                        If TRUE returns a AQSAPI_v2 object which is a two
+#'                        item list that contains header information returned
+#'                        from the API server mostly used for debugging
+#'                        purposes in addition to the data requested.
+#' @importFrom magrittr `%<>%`
+#' @examples #Returns an AQS_Data Mart_APIv2 S3 object or a tibble
+#'           #   containing annual performance evaluation data for ozone in
+#'           #   Alabmba for 2017 in RD format.
+#' \dontrun{
+#'         aqs_qa_annualperformanceevaltransaction_by_state(parameter = "44201",
+#'                                                  bdate = as.Date("20170101",
+#'                                                           format = "%Y%m%d"),
+#'                                                  edate = as.Date("20171231",
+#'                                                            format = "%Y%m%d")
+#'                                                  stateFIPS = "01"
+#'                                                          )
+#'          }
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object of quality assurance
+#'           performance evaluation data. for single monitoring site for the
+#'           sitenum, countycode and stateFIPS requested for the time frame
+#'           between bdate and edate. An AQS_Data_Mart_APIv2 is a 2 item named
+#'           list in which the first item ($Header) is a tibble of header
+#'           information from the AQS API and the second item ($Data) is a
+#'           tibble of the data returned.
+#' @export
+aqs_qa_annualperformanceevaltransaction_by_state <- function(parameter, bdate,
+                                                             edate, stateFIPS,
+                                                          return_header = FALSE)
+{
+  checkaqsparams(parameter, bdate, edate, stateFIPS, return_header)
+
+  params <- aqsmultiyearparams(parameter = parameter,
+                               bdate = bdate,
+                               edate = edate,
+                               stateFIPS = stateFIPS,
+                               service = "qaAnnualPerformanceEvaluations"
+                               )
+
+  tqaape <- purrr::pmap(.l = params, .f = aqs_services_by_state)
+  if (!return_header) tqaape %<>% aqs_removeheader
+  return(tqaape)
+}
+
+
+#' @title aqs_quarterlysummary_by_state
+#' @description \lifecycle{stable}
+#'                Returns a tibble or an AQS_Data Mart_APIv2 S3
+#'                object of quarterly summary data aggregated by stateFIPS.
+#' @note The AQS API only allows for a single year of quarterly summary to be
+#'         retrieved at a time. This function conveniently extracts date
+#'         information from the bdate and edate parameters then makes repeated
+#'         calls to the AQSAPI retrieving a maximum of one calendar year of data
+#'         at a time. Each calendar year of data requires a separate API call so
+#'         multiple years of data will require multiple API calls. As the number
+#'         of years of data being requested increases so does the length of time
+#'         that it will take to retrieve results. There is also a 5 second wait
+#'         time inserted between successive API calls to prevent overloading the
+#'         API server. This operation has a linear run time of
+#'         /(Big O notation: O/(n + 5 seconds/)/).
+#' @family Aggregate _by_state functions
+#' @inheritParams aqs_services_by_state
+#' @importFrom magrittr `%<>%`
+#' @param return_header If FALSE (default) only returns data requested.
+#'                        If TRUE returns a AQSAPI_v2 object which is a two
+#'                        item list that contains header information returned
+#'                        from the API server mostly used for debugging
+#'                        purposes in addition to the data requested.
+#' @return a tibble or an AQS_Data Mart_APIv2 S3 object that contains daily
+#'           summary statistics for the given parameter for a stateFIPS.
+#'           An AQS_Data Mart_APIv2 is a 2 item named list in which the first
+#'           item (\$Header) is a tibble of header information from the AQS API
+#'           and the second item (\$Data) is a tibble of the data returned.
+#' @examples # returns an aqs S3 object containing quarterly summaries for
+#'           #  FRM/FEM PM2.5 data for North Carolina between January
+#'           #  and February 2016
+#'  \dontrun{aqs_quarterlysummary_by_state(parameter = "88101",
+#'                                         bdate = as.Date("20160101",
+#'                                                         format = "%Y%m%d"),
+#'                                         edate = as.Date("20170228",
+#'                                                         format = "%Y%m%d"),
+#'                                         stateFIPS = "37"
+#'                                        )
+#'          }
+#' @export
+aqs_quarterlysummary_by_state <- function(parameter, bdate, edate, stateFIPS,
+                                          cbdate = NA_Date_, cedate = NA_Date_,
+                                          return_header = FALSE)
+{
+  AQS_domain <- "aqs.epa.gov"
+  checkaqsparams(parameter, bdate, edate, stateFIPS,
+                 cbdate, cedate, return_header)
+
+  params <- aqsmultiyearparams(parameter = parameter,
+                               bdate = bdate,
+                               edate = edate,
+                               stateFIPS = stateFIPS,
+                               service = "quarterlyData",
+                               cbdate = cbdate,
+                               cedate = cedate,
+                               AQS_domain = AQS_domain
+                               )
+
+  quarterlysummary <- purrr::pmap(.l = params, .f = aqs_services_by_state)
+  if (!return_header) quarterlysummary %<>% aqs_removeheader
+  return(quarterlysummary)
+}
