@@ -3,9 +3,9 @@ test_that("bybox functions", {
 testthat::skip_on_cran()
 testthat::skip_if_offline()
 server <- "AQSDatamartAPI"
-datamartAPI_user <- "test@aqs.api"
+datamartapi_user <- "test@aqs.api"
 
-  RAQSAPI::aqs_credentials(username = datamartAPI_user,
+  RAQSAPI::aqs_credentials(username = datamartapi_user,
                            key = "test"
                            )
 
