@@ -117,5 +117,25 @@ aqs_transactionsample_by_state(parameter = "45201",
                                )[[1]]$Header$status %>%
     expect_match(regexp = "Success")
 
+ aqs_qa_annualpeferomanceeval_by_state(parameter = "44201",
+                                       bdate = as.Date("20170101",
+                                                       format = "%Y%m%d"),
+                                       edate = as.Date("20171231",
+                                                       format = "%Y%m%d"),
+                                       stateFIPS = "01",
+                                       return_header = TRUE
+                                       )[[1]]$Header$status %>%
+    expect_match(regexp = "Success")
+
+ aqs_qa_annualperformanceevaltransaction_by_state(parameter = "44201",
+                                                  bdate = as.Date("20170101",
+                                                           format = "%Y%m%d"),
+                                                  edate = as.Date("20171231",
+                                                            format = "%Y%m%d"),
+                                                  stateFIPS = "01",
+                                                  return_header = TRUE
+                                                  )[[1]]$Header$status %>%
+    expect_match(regexp = "Success")
+
 
 })
